//
//  NSPropertyDescription+QuantumKitAdditions.m
//  QuantumKit
//
//  Created by Logan Collins on 7/9/13.
//  Copyright (c) 2013 Sunflower Softworks. All rights reserved.
//

#import "NSPropertyDescription+QuantumKitAdditions.h"

#import "QNKPersistentSyncCoordinator.h"
#import <objc/runtime.h>


@implementation NSPropertyDescription (QuantumKitAdditions)

static NSString * const QNKIsSyncableKey = @"com.quantumkit.syncable";

- (BOOL)qnk_isSyncable {
    NSNumber *syncable = objc_getAssociatedObject(self, (__bridge void *)QNKIsSyncableKey);
    if (syncable == nil) {
        NSDictionary *userInfo = [self userInfo];
        
        // Determine if the property is syncable
        id value = [userInfo objectForKey:QNKPropertyIsSyncableKey];
        
        BOOL isSyncable = NO;
        if ([value isKindOfClass:[NSNumber class]]) {
            isSyncable = [value boolValue];
        }
        else if ([value isKindOfClass:[NSString class]]) {
            isSyncable = ([[value lowercaseString] isEqualToString:@"true"] || [[value lowercaseString] isEqualToString:@"yes"] || [value isEqualToString:@"1"]);
        }
        
        syncable = [NSNumber numberWithBool:isSyncable];
        objc_setAssociatedObject(self, (__bridge void *)QNKIsSyncableKey, syncable, OBJC_ASSOCIATION_COPY);
    }
    return [syncable boolValue];
}

@end
